pygeoip._GeoIPMetaclass

Package pygeoip :: Class _GeoIPMetaclass |
[frames] | no frames]

# Type _GeoIPMetaclass

source code

    object --+
             |
          type --+
                 |
                _GeoIPMetaclass

Instance Methods
__call__(cls, *args, **kwargs) Singleton method to gets an instance without reparsing the database, the filename is being used as cache key. | source code
Inherited from `type`: `__delattr__`, `__eq__`, `__ge__`, `__getattribute__`, `__gt__`, `__hash__`, `__init__`, `__instancecheck__`, `__le__`, `__lt__`, `__ne__`, `__new__`, `__repr__`, `__setattr__`, `__subclasscheck__`, `__subclasses__`, `mro` Inherited from `object`: `__format__`, `__reduce__`, `__reduce_ex__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties
Inherited from `type`: `__abstractmethods__`, `__base__`, `__bases__`, `__basicsize__`, `__dictoffset__`, `__flags__`, `__itemsize__`, `__mro__`, `__name__`, `__weakrefoffset__` Inherited from `object`: `__class__`

Method Details

### __call__(cls, *args, **kwargs) (Call operator) | source code
Singleton method to gets an instance without reparsing the database, the filename is being used as cache key. Overrides: type.__call__